@@ -155,8 +155,8 @@ class ApiQueueTest(ApiTestBase):
         self.assertEquals(result["itemList"][1]["id"], song_a.id)
 
     def testIndexOrderByAlbum(self):
-        album_a = self.addAlbum(artist=self.addArtist(), title="A Title")
-        album_b = self.addAlbum(artist=self.addArtist(), title="B Title")
+        album_a = self.addAlbum(title="A Title")
+        album_b = self.addAlbum(title="B Title")
         song_a = self.addSong(artist=self.addArtist(), album=album_a)
         song_b = self.addSong(artist=self.addArtist(), album=album_b)
         self.addToQueue(song_a)
